@@ -502,6 +502,11 @@ impl Window {
 
   pub fn set_visible(&self, _visibility: bool) {}
 
+  pub fn set_focus(&self) {
+    //FIXME: implementation goes here
+    warn!("set_focus not yet implemented on Android");
+  }
+
   pub fn set_resizable(&self, _resizeable: bool) {}
 
   pub fn set_minimized(&self, _minimized: bool) {}
@@ -512,6 +517,16 @@ impl Window {
     false
   }
 
+  pub fn is_resizable(&self) -> bool {
+    warn!("`Window::is_resizable` is ignored on android");
+    false
+  }
+
+  pub fn is_decorated(&self) -> bool {
+    warn!("`Window::is_decorated` is ignored on Android");
+    false
+  }
+
   pub fn set_fullscreen(&self, _monitor: Option<window::Fullscreen>) {
     warn!("Cannot set fullscreen on Android");
   }
