@@ -66,6 +66,11 @@ impl Inner {
     }
   }
 
+  pub fn set_focus(&self) {
+    //FIXME: implementation goes here
+    warn!("set_focus not yet implemented on iOS");
+  }
+
   pub fn request_redraw(&self) {
     unsafe {
       if self.gl_or_metal_backed {
@@ -205,6 +210,16 @@ impl Inner {
     false
   }
 
+  pub fn is_resizable(&self) -> bool {
+    warn!("`Window::is_resizable` is ignored on iOS");
+    false
+  }
+
+  pub fn is_decorated(&self) -> bool {
+    warn!("`Window::is_decorated` is ignored on iOS");
+    false
+  }
+
   pub fn set_fullscreen(&self, monitor: Option<Fullscreen>) {
     unsafe {
       let uiscreen = match monitor {
