@@ -202,6 +202,10 @@ impl Window {
     }
     window.set_visible(attributes.visible);
     window.set_decorated(attributes.decorations);
+    if attributes.focus {
+      // FIXME: replace with present_with_timestamp
+      window.present();
+    }
 
     if !attributes.decorations && attributes.resizable {
       window.add_events(EventMask::POINTER_MOTION_MASK | EventMask::BUTTON_MOTION_MASK);
@@ -249,7 +253,7 @@ impl Window {
     let size: Rc<(AtomicI32, AtomicI32)> = Rc::new((w_size.0.into(), w_size.1.into()));
     let size_clone = size.clone();
 
-    window.connect_configure_event(move |_window, event| {
+    window.connect_configure_event(move |_, event| {
       let (x, y) = event.get_position();
       position_clone.0.store(x, Ordering::Release);
       position_clone.1.store(y, Ordering::Release);
@@ -268,7 +272,6 @@ impl Window {
     window.connect_window_state_event(move |_window, event| {
       let state = event.get_new_window_state();
       max_clone.store(state.contains(WindowState::MAXIMIZED), Ordering::Release);
-
       Inhibit(false)
     });
 
@@ -425,6 +428,15 @@ impl Window {
     }
   }
 
+  pub fn set_focus(&self) {
+    if let Err(e) = self
+      .window_requests_tx
+      .send((self.window_id, WindowRequest::Focus))
+    {
+      log::warn!("Fail to send visible request: {}", e);
+    }
+  }
+
   pub fn set_resizable(&self, resizable: bool) {
     if let Err(e) = self
       .window_requests_tx
@@ -456,6 +468,14 @@ impl Window {
     self.maximized.load(Ordering::Acquire)
   }
 
+  pub fn is_resizable(&self) -> bool {
+    self.window.get_resizable()
+  }
+
+  pub fn is_decorated(&self) -> bool {
+    self.window.get_decorated()
+  }
+
   pub fn drag_window(&self) -> Result<(), ExternalError> {
     if let Err(e) = self
       .window_requests_tx
@@ -590,6 +610,7 @@ pub enum WindowRequest {
   MinSize((i32, i32)),
   MaxSize((i32, i32)),
   Visible(bool),
+  Focus,
   Resizable(bool),
   Minimized(bool),
   Maximized(bool),
