@@ -388,6 +388,7 @@ impl UnownedWindow {
     let fullscreen = win_attribs.fullscreen.take();
     let maximized = win_attribs.maximized;
     let visible = win_attribs.visible;
+    let focus = win_attribs.focus;
     let decorations = win_attribs.decorations;
     let inner_rect = win_attribs
       .inner_size
@@ -416,6 +417,17 @@ impl UnownedWindow {
       unsafe { window.ns_window.makeKeyAndOrderFront_(nil) };
     }
 
+    if focus {
+      unsafe {
+        // if visible, we already send it
+        if !visible {
+          window.ns_window.makeKeyAndOrderFront_(nil);
+        }
+        let app: id = msg_send![class!(NSApplication), sharedApplication];
+        let () = msg_send![app, activateIgnoringOtherApps: YES];
+      };
+    }
+
     if maximized {
       window.set_maximized(maximized);
     }
@@ -456,6 +468,14 @@ impl UnownedWindow {
     }
   }
 
+  #[inline]
+  // Shortener for set_visible(true)
+  pub fn set_focus(&self) {
+    unsafe {
+      util::set_focus(*self.ns_window);
+    }
+  }
+
   pub fn request_redraw(&self) {
     AppState::queue_redraw(RootWindowId(self.id()));
   }
@@ -724,6 +744,22 @@ impl UnownedWindow {
     self.is_zoomed()
   }
 
+  #[inline]
+  pub fn is_resizable(&self) -> bool {
+    let is_resizable: BOOL = unsafe { msg_send![*self.ns_window, isResizable] };
+    is_resizable == YES
+  }
+
+  pub fn is_decorated(&self) -> bool {
+    let current_mask = unsafe { self.ns_window.styleMask() };
+    if current_mask
+      == NSWindowStyleMask::NSMiniaturizableWindowMask | NSWindowStyleMask::NSResizableWindowMask
+    {
+      return false;
+    }
+    true
+  }
+
   #[inline]
   pub fn set_fullscreen(&self, fullscreen: Option<Fullscreen>) {
     trace!("Locked shared state in `set_fullscreen`");
