@@ -152,6 +152,13 @@ impl Window {
     });
   }
 
+  #[inline]
+  pub fn set_focus(&self) {
+    unsafe {
+      force_window_active(self.window.0);
+    }
+  }
+
   #[inline]
   pub fn request_redraw(&self) {
     unsafe {
@@ -422,6 +429,17 @@ impl Window {
     window_state.window_flags.contains(WindowFlags::MAXIMIZED)
   }
 
+  #[inline]
+  pub fn is_resizable(&self) -> bool {
+    let window_state = self.window_state.lock();
+    window_state.window_flags.contains(WindowFlags::RESIZABLE)
+  }
+
+  pub fn is_decorated(&self) -> bool {
+    let window_state = self.window_state.lock();
+    window_state.window_flags.contains(WindowFlags::DECORATIONS)
+  }
+
   #[inline]
   pub fn fullscreen(&self) -> Option<Fullscreen> {
     let window_state = self.window_state.lock();
@@ -861,6 +879,10 @@ unsafe fn init<T: 'static>(
     menu::initialize(window_menu, window_handle, menu_handler);
   }
 
+  if attributes.focus {
+    force_window_active(win.window.0);
+  }
+
   Ok(win)
 }
 
