@@ -172,6 +172,11 @@ pub struct WindowAttributes {
   /// The default is `true`.
   pub visible: bool,
 
+  /// Whether the window should get focus upon creation.
+  ///
+  /// The default is `true`.
+  pub focus: bool,
+
   /// Whether the the window should be transparent. If this is true, writing colors
   /// with alpha values different than `1.0` will produce a transparent window.
   ///
@@ -212,6 +217,7 @@ impl Default for WindowAttributes {
       maximized: false,
       fullscreen: None,
       visible: true,
+      focus: true,
       transparent: false,
       decorations: true,
       always_on_top: false,
@@ -338,6 +344,18 @@ impl WindowBuilder {
     self
   }
 
+  /// Sets whether the window will be initially hidden or focus.
+  ///
+  /// See [`Window::set_focus`] for details.
+  ///
+  /// [`Window::set_focus`]: crate::window::Window::set_focus
+  #[inline]
+  pub fn with_focus(mut self) -> Self {
+    // in macOS with_focus and with_visible do the same thing
+    self.window.focus = true;
+    self
+  }
+
   /// Sets whether the background of the window should be transparent.
   #[inline]
   pub fn with_transparent(mut self, transparent: bool) -> Self {
@@ -611,6 +629,16 @@ impl Window {
     self.window.set_visible(visible)
   }
 
+  /// Bring the window to front and focus.
+  ///
+  /// ## Platform-specific
+  ///
+  /// - **iOS / Android:** Unsupported.
+  #[inline]
+  pub fn set_focus(&self) {
+    self.window.set_focus()
+  }
+
   /// Sets whether the window is resizable or not.
   ///
   /// Note that making the window unresizable doesn't exempt you from handling `Resized`, as that event can still be
@@ -660,6 +688,25 @@ impl Window {
     self.window.is_maximized()
   }
 
+  /// Gets the window's current resizable state.
+  ///
+  /// ## Platform-specific
+  ///
+  /// - **iOS / Android:** Unsupported.
+  #[inline]
+  pub fn is_resizable(&self) -> bool {
+    self.window.is_resizable()
+  }
+
+  /// Gets the window's current decoration state.
+  ///
+  /// ## Platform-specific
+  ///
+  /// - **iOS / Android:** Unsupported.
+  pub fn is_decorated(&self) -> bool {
+    self.window.is_decorated()
+  }
+
   /// Sets the window to fullscreen or back.
   ///
   /// ## Platform-specific
